@@ -1,11 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-""" This package implement Packet Analysis with
-network sniffer or pcap file reader. """
+"""
+This package prints and sniffs the packets.
+"""
 
 ###################
-#    This package implement Packet Analysis with network sniffer or pcap file reader.
+#    This package prints and sniffs the packets.
 #    Copyright (C) 2021  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
@@ -22,17 +23,29 @@ network sniffer or pcap file reader. """
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-__version__ = "0.0.1"
+__version__ = "1.0.0"
+__author__ = "Maurice Lambert"
+__author_email__ = "mauricelambert434@gmail.com"
+__maintainer__ = "Maurice Lambert"
+__maintainer_email__ = "mauricelambert434@gmail.com"
+__description__ = """
+This file implements a network sniffer.
+"""
+license = "GPL-3.0 License"
+__url__ = "https://github.com/mauricelambert/PacketAnalysis"
+
+copyright = """
+PacketAnalysis  Copyright (C) 2021  Maurice Lambert
+This program comes with ABSOLUTELY NO WARRANTY.
+This is free software, and you are welcome to redistribute it
+under certain conditions.
+"""
+__license__ = license
+__copyright__ = copyright
+
 __all__ = ["Sniffer", "PacketPrinter", "packets_analysis"]
 
 from .PacketPrinter import PacketPrinter
 from .Sniffer import Sniffer, main as packets_analysis
 
-print(
-    """
-PacketsAnalysis  Copyright (C) 2021  Maurice Lambert
-This program comes with ABSOLUTELY NO WARRANTY.
-This is free software, and you are welcome to redistribute it
-under certain conditions.
-"""
-)
+print(copyright)
